#declare Temp_Vers = version
#version 3.0

/*
 * Model of a metal chain. Borrows heavily from the TORDEMO.POV file
 * supplied with POV-Ray 3.0, but has been generalized to accept
 * the number of links as a parameter.
 *
 * Chain is generated with the bottom of the first link touching
 * the origin, with the chain stretching up the y axis. Each
 * link is 2 POVunits long and 1 POVunit wide. The scale is
 * intended to be 1 POVunit == 1 inch.
 *
 * T_chainlink is the texture for the chain links. If not
 * defined by the including file a default will be used.
 *
 * Chain_Num_Links is the number of links in the chain.
 * If not defined by the including file the default is 7.
 *
 * Last modified 6/27/98 by Denton Gentry.
 */

#ifdef ( T_chainlink )
// Do nothing, use the texture declared in the including file
#else
// This is the texture from TORDEMO.POV, from which this model
// is derived.
#declare T_chainlink = texture {
	pigment { BrightGold }
	finish {
		ambient .1 
		diffuse .4 
		reflection .25 
		specular 1
		metallic 
	}
}
#end

#declare Half_Torus = difference {
	torus { 0.75, 0.25
		sturm
		rotate <-90,0,0>
	}
	box { <-2, 0, -1>, <2, 2, 1> }
}

#declare Link = merge {
	object { Half_Torus
	}
	cylinder { <-0.75,0,0>, <-0.75,1,0>, 0.25
		open
	}
	cylinder { < 0.75,0,0>, < 0.75,1,0>, 0.25
		open
	}
	object { Half_Torus
		rotate <180,0,0>
		translate <0,1,0>
	}

	texture { T_chainlink }
}

#ifdef ( Chain_Num_Links )
// Do nothing, use declare from including file
#else
#declare Chain_Num_Links = 7
#end

#declare Chain_Link_Count = 0

#declare Chain = merge {
#while (Chain_Link_Count < Chain_Num_Links)
	object {
		Link
		translate <0, 2*Chain_Link_Count, 0>
		rotate <0, 90*Chain_Link_Count, 0>
	}
	#declare Chain_Link_Count=Chain_Link_Count + 1
#end
}

#version Temp_Vers
