#include "colors.inc"    // The include files contain
#include "shapes.inc"    // pre-defined scene elements
#include "finish.inc"
#include "metals.inc"
#include "stones.inc"
#include "glass.inc"

#version 3.0

/*
 * Scene file for rendering a force field surrounding a
 * Progenitor Holy Symbol. This scene is from a Rolemaster
 * game the author participates in.
 *
 * Last modified 6/30/98 by Denton Gentry.
 */

global_settings {
	assumed_gamma 1.8
	ambient_light rgb<1, 1, 1>
}


// Snatched from povlib.inc, http://texlib.povray.org
#declare Streaky_Steel_Metal = texture {
//  pigment { color rgb <.75, .75, .75> }
  pigment { color rgb <.9, .9, .9> }
  finish {
    specular .7
//   diffuse .4
    diffuse .6 
    brilliance 6
    roughness .0082
    reflection .32
  }
  normal {
    wrinkles .6
    scale <.051, 30, .051>
    rotate <0, 0, 45>
  }
}

// Texture by Chuck Fusner, http://www.enter.net/~cfusner
#declare RoughStone = texture { //rough stone texture...
	pigment { //nice and random on the pigment.
		granite
		color_map {
		[ 0 rgb .5 ]
		[ .25 rgb .65 ]
		[ .5 rgb .5 ]
		[ .75 rgb .7 ]
		[ 1 rgb .5 ]
		}
		frequency 100
	}
	normal { /*love that crackle! It's apparently quite
                 computation intensive, but with just the
                 right turbulence, it's got a range of apps.*/
		crackle 1
		warp {
		turbulence <.5,.5,.5> /*no more than this for a rough
                                    stone effect. And less will
                                    look more "crystaline"*/
		lambda 2 //these you can tinker with
		octaves 6 //for a variety of effects
		omega .5 //though here they are at defaults.
		}
	}
	finish {
		specular .1 roughness 1
		diffuse .55

	}
}

#declare T_unlife_forcefield = texture {
	pigment { color rgbf <0.87, 0.58, 0.98, 0.9> } // Light_Purple
	finish {
		ambient 0.5
		diffuse 0.1
		brilliance 1.0
		reflection 0.001
		refraction 1
		ior 1.1
		phong 0.3
		phong_size 30

		caustics 0.2

		irid {
 			0.35
			thickness .4
			turbulence .6
		}
	}
}



/*
 * Progenitor holy symbol mounted to the floor.
 */
#include "symbol.inc"
object {
	object { Progenitor_Symbol }
	rotate <0,-45,0>
	no_shadow
}


/*
 * Force field generator hanging from the ceiling
 */
#declare Chain_Num_Links = 25
#declare T_chainlink = texture { T_Gold_1A }
#include "chain.inc"

merge {
	object { 
		/*
		 * The Chain model was created with 1 unit == 1 inch.
		 * The rest  of this scene is modeled with 1 unit == 1 foot.
		 * Convert the chain to the scale of the scene.
		 */
		Chain
		scale <1/12, 1/12, 1/12>
	}

	difference {
		sphere { <0,0,0>, 0.45 }
		box { <-1, -1, -1>, <1, 0, 1> }

		texture { T_Gold_1A }
	}

	sphere { <0,0,0>, 0.15
		texture { T_Ruby_Glass }
	}

	// Move the whole apparatus above the Progenitor symbol
	translate <0, 5.30, 0>
}


/*
 * Unlife force field surrounding the Progenitor holy symbol.
 *
 * I'd like this to be an SOR object, it would be faster to render.
 * But with POV 3.0.2 there are bizarre screen artifacts at height
 * 4.0 or so, several lines of black pixels mixed in with the
 * field. With a lathe there are no bizarre artifacts.
 */
lathe {
	cubic_spline
	7,
	<2.50, -1.0>,
	<2.50,  0.0>,
	<2.10,  3.5>,
	<1.50,  4.5>,
	<0.90,  5.0>,
	<0.01,  5.5>,
	<0.00,  5.51>

	texture { T_unlife_forcefield }
}



// floor
plane {
	<0,1,0>, 0
	texture { Streaky_Steel_Metal }
}


/*
 * The inner walls form a "cage" built by the progenitors.
 * It is made of an unknown material which glows
 * faintly with energy.
 */
difference {
	box {
		<0,0,-80>,
		<80,50,0>
	}

	// Cut an alcove from the box for the symbol to stand in. 
	cylinder {
		<0,-1,0>,
		<0,51,0>,
		5
	}

	// T_Crack3 and T_Crack4 are both pretty good for
	// the crackling energy effect. 4 is better.
	texture { T_Crack4 }
}


/*
 * The outer walls are made of normal stone.
 */
// right side outer wall
difference {
	box {
		<-100,  0, -93>,
		< -12, 50,  12>
	}

	// cut a hole for the archway
	union {
		cylinder { <-11, 10, -35>, <-100, 10, -35>, 10 }
		box { <-100, 0, -45>, < -11, 10, -25> }
	}

	texture { RoughStone }
}

// far side outer wall.
plane {
	<0, 0, 1>, -92
	texture { RoughStone }
}

// A textured ceiling distracts from the scene, so we don't have one.



#declare T_archway = texture { T_Stone13 }
#include "archway.inc"
object {
	Archway
	rotate <0,90,0>
	translate <-14.5, 0, -35>
}


// illuminate the archway.
light_source {
	<-6,10,-29>
	color Gray65	// a somewhat dimmer light
	fade_distance 10
	fade_power 3
}

light_source {
	<0, 10, 20>
	color White
}

/*
 * A light to give everything a purple cast, like the force field is
 * glowing. A halo effect on the force field doesn't work very well,
 * making the transmittance of the field high enough to transmit the
 * halo makes the (highly polished) progenitor symbol look terrible
 * from the reflections.
 *
 * The light illuminates everything close to the force field. It
 * fades before it reaches the back wall (the far wall would otherwise
 * reflect the intense purple light directly back into the camera).
 */
light_source {
	<-10, 10, 20>
	color Light_Purple
	fade_distance 60
	fade_power 5
}


camera {
	location <-2, 4, 12>
	look_at  <0, 3, 0>
}
