#declare Temp_Vers = version
#version 3.0

/*
 * The Progenitor Holy Symbol. This object is from a Rolemaster
 * game the author participates in.
 *
 * T_progenitorsym_body is the texture of the body of the
 * symbol, T_progenitorsym_boss is the texture for the center
 * boss device. Defaults are silver for the body and gold for the boss.
 * Nominally this model was laid out so 1 POV-unit == 1 foot, making
 * this symbol roughly 3 1/2 feet high and 3 1/2 feet wide. It is
 * created on the origin, with the center arm running along the X
 * axis.
 *
 * You must #include metals.inc before including this file.
 *
 * Last modified 6/27/98 by Denton Gentry.
 * This file is in the public domain, and
 * is free for derivative use.
 */

#ifdef ( T_progenitorsym_body )
// Do nothing, use the texture declared in the including file
#else
#declare T_progenitorsym_body = texture { pigment { P_Silver3 } finish { F_MetalC  } }
#end

#ifdef ( T_progenitorsym_boss )
// Do nothing, use the texture declared in the including file
#else
#declare T_progenitorsym_boss = texture { pigment { P_Gold3 } finish { F_MetalC } }
#end

#declare Progenitor_Symbol = merge {
	// vertical body of symbol
	cylinder {
		<0,0,0>,
		<0,4,0>,
		0.5

		texture { T_progenitorsym_body }
	}

	// top dome
	sphere {
		<0,4,0>, 0.5

		texture { T_progenitorsym_body }
	}

	// horizontal arm of symbol
	cylinder {
		<-1.5,3.00, 0.0>,
		<1.5, 3.00, 0.0>,
		0.5

		texture { T_progenitorsym_body }
	}

	// left hand cap of horizontal arm
	cone {
		<0,0,0>, (1/sqrt(3))
		<0,1,0>, 0

		clipped_by { plane {<-1,-sqrt(3),0>, -(0.5/sqrt(3))} }

		scale <1, 1, 0.75*sqrt(3)>

		// First center the base at the origin
		rotate <0,0,30>
		translate <0.005, -0.29, 0>

		// Now move it into position
		rotate <0,0,-90>
		translate <1.50,3.00,0>

		texture { T_progenitorsym_body }
	}

	// right hand cap of horizontal arm
	cone {
		<0,0,0>, (1/sqrt(3))
		<0,1,0>, 0

		clipped_by { plane {<-1,-sqrt(3),0>, -(0.5/sqrt(3))} }

		scale <1, 1, 0.75*sqrt(3)>

		// First center the base at the origin
		rotate <0,0,30>
		translate <0.005, -0.29, 0>

		// Now move it into position
		rotate <0,180,90>
		translate <-1.50,3.00,0>

		texture { T_progenitorsym_body }
	}

	cylinder {
		<0,3.25, 0.25>,
		<0,3.25,-0.25>,
		0.70

		scale <2.0, 1.0, 1.0>
		texture { T_progenitorsym_boss }
	}

	finish {
		ambient 1.0
		diffuse 0
	}
}

#version Temp_Vers
